@@ -33,20 +33,14 @@ from blueapps.opentelemetry.utils import inject_logging_trace_info
 
 
 def setup_trace_config(
-    service_name: str,
-    bk_data_id: int,
-    otel_sampler: str,
-    otel_grpc_host: str,
-    bk_data_token: str = "",
+    service_name: str, bk_data_id: int, otel_sampler: str, otel_grpc_host: str, bk_data_token: str = "",
 ):
     if settings.ENVIRONMENT == "dev":
         # local environment, use jaeger as trace service
         # docker run -p 16686:16686 -p 6831:6831/udp jaegertracing/all-in-one
         trace.set_tracer_provider(TracerProvider(resource=Resource.create({SERVICE_NAME: service_name})))
         jaeger_exporter = JaegerExporter(
-            agent_host_name="localhost",
-            agent_port=6831,
-            udp_split_oversized_batches=True,
+            agent_host_name="localhost", agent_port=6831, udp_split_oversized_batches=True,
         )
         trace.get_tracer_provider().add_span_processor(BatchSpanProcessor(jaeger_exporter))
     else:
@@ -54,11 +48,7 @@ def setup_trace_config(
         trace.set_tracer_provider(
             tracer_provider=TracerProvider(
                 resource=Resource.create(
-                    {
-                        "service.name": service_name,
-                        "bk_data_id": bk_data_id,
-                        "bk.data.token": bk_data_token,
-                    },
+                    {"service.name": service_name, "bk_data_id": bk_data_id, "bk.data.token": bk_data_token},
                 ),
                 sampler=_KNOWN_SAMPLERS[otel_sampler],
             )
@@ -83,11 +73,7 @@ def setup_by_settings():
         otel_grpc_host = os.getenv("BKAPP_OTEL_GRPC_HOST") or getattr(settings, "BKAPP_OTEL_GRPC_HOST", None)
         otel_bk_data_token = os.getenv("BKAPP_OTEL_BK_DATA_TOKEN") or getattr(settings, "BKAPP_OTEL_BK_DATA_TOKEN", "")
         setup_trace_config(
-            service_name,
-            bk_data_id,
-            otel_sampler,
-            otel_grpc_host,
-            bk_data_token=otel_bk_data_token,
+            service_name, bk_data_id, otel_sampler, otel_grpc_host, bk_data_token=otel_bk_data_token,
         )
         BKAppInstrumentor().instrument()
         # 将Trace信息配置到项目日志中
@@ -95,5 +81,7 @@ def setup_by_settings():
         inject_logging_trace_info(settings.LOGGING, ("verbose",), trace_format)
         configure_logging(settings.LOGGING_CONFIG, settings.LOGGING)
     # metrics
-    SaaSMetricsInstrumentor().instrument()
-    celery_app.steps["worker"].add(MetricsServerStep)
+    enable_metrics = os.getenv("ENABLE_METRICS") or getattr(settings, "ENABLE_OTEL_METRICS", False)
+    if enable_metrics:
+        SaaSMetricsInstrumentor().instrument()
+        celery_app.steps["worker"].add(MetricsServerStep)
